/*  $Id: AppLogErrHandler.java 1220 2011-09-11 14:03:19Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2010 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

/**
 * Trace errors with application logging facilities.
 * @version $Id: AppLogErrHandler.java 1220 2011-09-11 14:03:19Z sdevaux $
 * @author Sebastien Devaux
 */ 
public class AppLogErrHandler implements ErrorHandler {
    /**
     * Create new AppLogErrHandler
     */ 
    public AppLogErrHandler() {
        _errCount=0;
        _fatal=false;
    }
    // Handler.handle()
    public void handle(Error e) {
        App app=App.get();
        _errCount++;
        String msg=e.getMessage();
        switch (e.getLevel()) {
            case FATAL :
                app.log().fatal(msg);
                _fatal=true;
                break;
            case ERR :
                app.log().error(msg);
                break;
            default :
                app.log().warn(msg);
                break;
        }
        Exception ex=e.getException();
        if (ex!=null) {
            app.log().debug("Exception: "+ex);
        }
        if (_fatal) {
            app.exit(1);
        }
    } 
    // ErrorHandler.checkOnly()
    public boolean checkOnly() {
        SLogger log=App.get().log();
        boolean res=_errCount>0;
        log.debug("Error checking - error count: "+_errCount);
        log.debug("Error checking - fatal error: "+_fatal);
        return res;
    }
       
    public boolean checkAndReset() {
    	boolean res=checkOnly();
    	_errCount=0;
    	return res;
    }

    /** set true when a fatal error is encountered */
    boolean _fatal;
    /** error counter */
    int _errCount;
}
