/*  $Id: TestStateMachine.java 1335 2012-08-25 13:27:49Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002-2012 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package test;

import org.junit.*;
import static org.junit.Assert.*;

import net.eduvax.util.App;
import net.eduvax.util.StateMachine;

/** 
 * Finit state machine unit test.
 * Implement simple state machine : states are integer, transitions are 
 * triggered by chars. Below is the transition graph :
 * <pre>
 *  0 ---A---} 1 ---B---} 2 ---C---} 3 
 *  ^          |          |
 *  |          Z          |
 *  +-------B-------------+
 * </pre>
 */
public class TestStateMachine {
    private StateMachine<Integer,Character> _stateMachine;
    
    @Before public void setUp()
    {
        App.init();
        _stateMachine=new StateMachine<Integer,Character>(0);
        _stateMachine.addTransition(0,'A',1);
        _stateMachine.addTransition(1,'B',2);
        _stateMachine.addTransition(2,'C',3);
        _stateMachine.addTransition(2,'B',0);
        _stateMachine.addTransition(1,'Z',1);
    }

    @Test public void testStateMachine()
    {
        assertEquals("initial state",0,_stateMachine.getState().intValue());
        assertFalse("Can't exit 0 state with Z",
                                _stateMachine.runTransition('Z'));
        assertEquals("0 State",0,_stateMachine.getState().intValue());
        assertTrue(_stateMachine.runTransition('A'));
        assertEquals(1,_stateMachine.getState().intValue());
        assertTrue(_stateMachine.runTransition('Z'));
        assertEquals(1,_stateMachine.getState().intValue());
        assertFalse(_stateMachine.runTransition('A'));
        assertEquals(1,_stateMachine.getState().intValue());
        assertTrue(_stateMachine.runTransition('B'));
        assertEquals(2,_stateMachine.getState().intValue());
        assertFalse(_stateMachine.runTransition('A'));
        assertEquals(2,_stateMachine.getState().intValue());
        assertTrue(_stateMachine.runTransition('B'));
        assertEquals(0,_stateMachine.getState().intValue());
        _stateMachine.runTransition('A');
        _stateMachine.runTransition('B');
        assertTrue(_stateMachine.runTransition('C'));
        assertEquals(3,_stateMachine.getState().intValue());
        assertFalse(_stateMachine.runTransition('A'));
        assertEquals(3,_stateMachine.getState().intValue());
        assertFalse(_stateMachine.runTransition('B'));
        assertEquals(3,_stateMachine.getState().intValue());
        assertFalse(_stateMachine.runTransition('C'));
        assertEquals(3,_stateMachine.getState().intValue());
        assertFalse(_stateMachine.runTransition('Z'));
        assertEquals(3,_stateMachine.getState().intValue());
    }
}
